*	FILE GENERATES REPLICATION FOR PAPER THE TIMING OF ELECTIONS AFTER THE COUP D'ETAT (WITH HEIN GOEMANS)
*	FOR BRITISH JOURNAL OF POLITICAL SCIENCE
*	This version: May 2013

*	INSTRUCTIONS:

*	place this file goemansmarinovbjps_rep.do 
*	and goemansmarinovbjps_rep.dta in a directory;
*	set that directory as STATA's working directory
*	run this file: goemansmarinovbjps_rep.do;

*	DATA

*	the file takes a data file goemansmarinovbjps.dta,
*	containing information on elections
*	(NELDA 1945-2010 see Hyde and Marinov Political Analysis 2012)
*	and information on coups (1960-2001 Archigos, See Goemans Gleditsch et al)
*	and ODA data from DAC database OECD (http://www.oecd.org/dac/stats/data.htm)
*	and creates descriptives, tables, graphs for BJPS paper

*	GRAPHS

*	all graphs/images ... generated go to -> ../graphs
*	creating a dir for graphs... 	

	capture mkdir graphs

*	LATEX

*	to include in latex file; move manually to local Latex dir  -> ../img_coups 
*	or wherever Latex can find them

*	START


* 	HOW IT WORKS

* 	(1) use exitcode in Archigos to pick the coup d'etats; use exitcode (2) again to code countries lead by successful coup-leaders;
* 	(3) code helpful variables such as days to election, coup-spell id and duration, whether coup has ended and whether it ends in election
*   (4) code some vars related to external dependence and economy such as odadep and lngdppc

*	comment out before sending out:
*	cd "/Users/nvm4/Documents/E-Library/Democracy/Goemans Marinov Coup/Publication/repdata"*

*	Set scheme to whatever is appropriate: publication or review

*	set scheme s2mono
 	set scheme s2color
* 	set scheme s1color
	drop _all
	clear matrix
	clear mata
	set mem 512m
	set matsize 800
	capture log close

	use "goemansmarinovbjps_rep.dta"

*	checks

	set more off

	assert ccode!=. if year>=1945
	drop if ccode==.
	sort ccode year
	tsset ccode year


*	Random comments

*	no aid data for Trinidad_and_Tobago/Morocco/Taiwan

* 	Correcting this to refect an update in June 08
*	Changing exit code to 3 (from 8): 
*	FJI-2000-1  950 FJI Bainimarama  29/05/2000  14/07/2000 

	replace exitcode="4 0 3" if country=="Fiji" & year==2000


*	ALL VARS will be generated at the start:


	gen el=(length(electionid)>0 & length(electionid)<1000 )
	label var el "election"
	move el electionid

*	N  of countries holding reg elections									

*	EL_N
*	First, we will generate a var with number of election rounds held in country in year
*	because electionid conists of 16 chars for each election round help, can divide its length to get the n of rounds in each year

	gen el_n=int(length(electionid)/16)
	label var el_n "number of elections held by cry in year"
	move el_n el

*	Second, we will collect info on election-quality related questions at the country-level for all these country-years having at least one election
*	var q`i' will be 1 if at least one question for at least one round for at least one  election is "yes"
*	CONDITIONALS ALERT:	now bq47 and nq47 (if election w-observed, fraud?) is 0 even if election not monitored

*	BQ
*	Prefix `b' is for BINARY: at least one `yes'							

*	foreach i of numlist 1 3 4 5 20 39 45/47 50/53 55/58		{

*		gen bq`i'=strpos(q`i',"yes")>0 if electionid!=""

*	}

*	BQU						
*	this is similar except that it counts unclear as a potential yes
								
*	foreach i of numlist 1/58	{						
								
*		gen bqu`i'=(strpos(q`i',"yes")>0 | strpos(q`i',"unclear")>0) if electionid!=""						
								
*	}							
								
*								
								
								


*	EL_RCI
*	Elections, type and who holds:														
*	regimes where elections have NOT been suspended - reverse q1 so that interpretation is more intuitive														

	replace bq1=1-bq1
	label var bq1 "=1-bq1, ele have not been suspended"

	gen el_rci = 1 if el==1 & bq3==1 & bq4==1 & bq5==1 & bq20==1


	gen ellast = l1.el_rci
	replace ellast = 0 if l1.el_rci==.
	label var ellast "After Election"

	label var el_rci "incumbent faces periodic multi -party & -candidate elections"
	move el_rci el

	sort ccode year

* 	and the lags ...
 
	forvalues i = 1(1)7 {

		gen el_rcil`i'=l`i'.el_rci  

	}

	forvalues i = 1(1)7 {

		replace el_rci = el_rcil`i' if el_rci==.

	}

	replace el_rci=0 if el_rci==.

*	done!
*	seems like anyone for who we know:
*	held an election in the last 7 years that had q3, 4 5 and 20 positive
*	... is considered to be having a regular opposed election in which inc competes

	drop el_rcil* 

	gen shorteldem=(l1.el_rci==1 & l2.el_rci==0)
	label var shorteldem "=(el_rci==1 & l1.el_rci==0)" 

*	EL_M, EL_W, EL_F
*	Whether (at least one) election was monitored and obs report

	gen el_m=(bq45==1) if bq45!=.
	label var el_m "at least one round of an election i-observed in yr in cry"
	move el_m el

	gen el_w=(bq46==1) if bq46!=.
	label var el_w "(if i-observed) at least one round of an election West-observed in yr in cry"
	move el_w el

	gen el_f=(bq47==1) if bq47!=.
	label var el_f "(if i-observed) fraud alleged in at least one round of an election W-obs in yr in cry"
	move el_f el
	replace el_f=. if el_w==0

	label def fraudyesno 0 "clean" 1 "FRAUD"
	label val el_f fraudyesno
	label def obs 0 "Election Not Observed" 1 "Election Observed"
	label val el_w obs



*	ODA TOTALS

	gen oda_current=oda						
	move oda_curr oda
	replace oda=oda/cf_1995
	gen lnoda=log(oda)
	label var oda "tot oda in 1995 const $, Sahr deflator"
	label var lnoda "log of tot oda in 1995 const $, Sahr deflator"
	gen lnodaoecd=lnoda

	tsset ccode year
	sort ccode year


*	need to replace with missing anything after 2004 and before 1960

	foreach i of varlist ODAAUSTRALIA ODAAUSTRIA ODABELGIUM ODACANADA ODACARDB ODADENMARK ODAFINLAND ///
	ODAFRANCE ODAGERMANY ODAGREECE ODAIRELAND ODAITALY ODAJAPAN ODALUXEMBOURG ODANETHERLANDS ODANEW_ZEALAND /// 
	ODANORWAY ODAPORTUGAL ODASPAIN ODASWEDEN ODASWITZERLAND ODAUNITED_KINGDOM ODAUNITED_STATES ODAAFRICAN_DEV__FUND /// 
	ODAAF__D_B ODAAS__D_B ODAAS__D_B_SPECIAL_FUNDS ODAArab_Agencies ODACOUNCIL_OF_EUROPE ODAEBRD ODAEC ODAEIB ODAGEF /// 
	ODAIBRD ODAIDA ODAIDB ODAIDB_SPECIAL_OPER__FUND ODAIFAD ODAIFC ODAIMF  ODAIMF_TRUST_FUND ODAMontreal_Protocol /// 
	ODANORDIC_DEVELOPMENT_FUND ODAOTHER_UN ODASAF_and_ESAF  ODAUNDP ODAUNFPA ODAUNHCR ODAUNICEF ODAUNRWA ODAUNTA ///
	ODAUN_AGENCIES ODAWFP																							{

		replace `i'=. if year<1960 & year>2004

	}


*	Generating 1995 const dollar figures for aid quantities of interest
*	remember that euro is sum of bilateral aid in euro member states; EC is the Community's multilateral aid"

	gen odaus=ODAUNITED_STATES

	egen odaeumem= rsum(ODAAUSTRIA ODABELGIUM ODADENMARK ODAFINLAND ODAFRANCE ODAGERMANY ODAGREECE ODAIRELAND ODAITALY /// 
	ODALUXEMBOURG ODANETHERLANDS ODANORWAY ODAPORTUGAL ODASPAIN ODASWEDEN ODASWITZERLAND ODAUNITED_KINGDOM)

	gen odaec = ODAEC
	gen odauk = ODAUNITED_KINGDOM
	gen odafr = ODAFRANCE
	gen odaswe=ODASWEDEN
	gen odaeuro=odaeumem

	foreach i in us euro ec uk fr swe	{

		gen odadep`i'oda=oda`i'/oda_curr
		replace oda`i'=oda`i'/cf_1995
		gen odadep`i'=oda`i'/gdpM
		gen lnoda`i'=log(oda`i'+1)
		label var odadep`i'oda "oda `i' over all oda, curr doll"
		label var odadep`i' "oda `i' over gdpM, 1995 const $ both"
		label var oda`i' "tot `i' oda in 1995 const $, Sahr deflator"
		label var lnoda`i' "log of tot `i' oda in 1995 const $, Sahr deflator"

	}

*	ODADEP
*	measures of dep on aid, gdppc, growth

	gen odadep=(oda*1000000)/gdpM
	label var odadep "Aid Dependence, =(oda*1000000)/gdpM"




*	GDP AND POP																									
*	wbpop is not labelled...
	label var wbpop "population, in total persons, from World Bank"

	gen lngdpM=log(gdpM)
	label var lngdpM "log of gdpM, in const 1995 dollars"

	gen lnwbpop=log(wbpop)
	label var lnwbpop "log of World Bank population"




*	COUPS																																					


*	postCW measures POSTCW (1991) and 1990 and 1989

	capture drop postcw
	capture label drop cw
	gen postcw=0 if year>=1945 & year<=1990
	replace postcw=1 if year>=1991 & year<=2004
	label def cw 0 "1945-1990" 1 "1991-2004" 
	label val postcw cw


*	N OF COUPS

*	correcting - fail==1 for 2004 even if no one failed, need to correct
*	when below condition is satisfied, means exitcode=-888 still in office except Switzerland where 0 because they change every year

	replace fail=0 if year==2004 & wordcount(exitcode)==1

*	this part generates variables from the data we have

*	var HCOUPS is n of coups in year, starting with 0

	gen hcoups=0 if exitcode!=""
	label var hcoups "n exitcode>=3 and <=8 or =16, coups per Archigos 2"

* 	Looping over exitcode to get the correct n of coups

	local N=_N

	forvalues j=1(1)`N' 																																																{

		local k=wordcount(exitcode[`j'])

		forvalues i=1/`k'																																																{

			if `k'==1																																																	{

				*				someone in previous year had that exitcode and failed in current year

				if ( ( ( real( word(exitcode[`j'-1], -1) )>=3 & real( word(exitcode[`j'-1], -1) )<=8 ) | real( word(exitcode[`j'-1], -1) )==16 ) & fail[`j']==1 & real( substr(ein_outdate[`j'],-14,4))==year[`j']) 	{

						replace hcoups=hcoups+1 in `j'
				}

				if ( ( ( real( word(exitcode[`j'], 1) )>=3 & real( word(exitcode[`j'], 1) )<=8 ) | real( word(exitcode[`j'], 1) )==16 ) & fail[`j']==1 & real( substr(ein_outdate[`j'],-4,4))==year[`j']) 				{

						replace hcoups=hcoups+1 in `j'
				}

			}

			else 																																																		{

				if ( ( ( real( word(exitcode[`j'], `i') )>=3 & real( word(exitcode[`j'], `i') )<=8 ) | real( word(exitcode[`j'], `i') )==16 ) & fail[`j']==1 ) 															{

						replace hcoups=hcoups+1 in `j'
			
				}								
			}
		}		
	}




* 	Simple dummy HCOUP (=at least one coup in year)

	gen hcoup=(hcoups>0) if hcoups!=.
	label var hcoup "at least one coup in year, based on HCOUPS (derived from EXITCODE in Archigos)"


* 	if needed, generate n of autogolpes
* 	gen hcoupsauto=(hcoup==1 | autogolpe==1) if exitcode!=""

* 	var ONES is for pie charts of coups: coup-year is 1 if HCOUP, missing otherwise

	capture drop ones
	gen ones=1 if hcoup==1
	label var ones "1 for coup-years (HCOUP=1), missing otherwise"


* 	var SUMHCOUPS this is for an overtime graph

	egen sumhcoups=sum(hcoups), by(year)
	label var sumhcoups "number of coups"


*	It is also of interest to know what kind of leader country had at end of year - one who came to power through a coup d'etat or no?
*	This will be based ona new var HOWENTER = how previous leader exited

	capture drop howenter
	gen howenter=. if exitcode!=""

	local N=_N

	forvalues j=1(1)`N' 																																{

		local k=wordcount(exitcode[`j'])

			if `k'==1																																	{

				if ( fail[`j'-1]==1 & real( substr(ein_outdate[`j'],-14,4))==year[`j']-1) 																{

						local j1=`j'-1
						replace howenter=real( word(exitcode[`j'-1], -1) ) in `j1'
				}
			}

			if `k'==1																																	{

				if ( fail[`j']==1 & real( substr(ein_outdate[`j'],-4,4))==year[`j'] & real( substr(ein_outdate[`j'],-14,4))==year[`j']) 				{

						replace howenter=real( word(exitcode[`j'], -1) ) in `j'
				}

			}

			else 																																		{

				if ( fail[`j']==1 & (real( substr(ein_outdate[`j'],-4,4) )!=year[`j']  | year[`j']==2004)) 	{

						replace howenter=real( word(exitcode[`j'], -2) ) in `j'
				
				}

				if ( fail[`j']==1 & real( substr(ein_outdate[`j'],-4,4) )==year[`j'] & year[`j']!=2004)  	{

						replace howenter=real( word(exitcode[`j'], -1) ) in `j'
				
				}


			}
		
				
	}


* 	... filling in the rest of HOWENTER

	replace howenter=l1.howenter if howenter==. & l1.howenter!=. & fail!=.
	label var howenter "how leader in office at end of year entered (=prev exitcode)"


*	COUPENTRY
*	Now we can create a variable for country with coup-installed leader by exploiting howenter

	gen coupentry=( (howenter>=3 & howenter<=8) | howenter==16) if howenter!=.
	label var coupentry "country has coup-installed leader at end of year"


*	MILCOUP
*	Now we can create a variable for country with military-installed leaders by exploiting howenter
*	Note because of how Archigos works in some cases (Portugal 1974) where the military starts to hand over power in a regular
*	manner to other military actors this variable will be 0 in some cases even as it likely should be 1

	gen milcoup=( (howenter>=5 & howenter<=6) | howenter==16) if howenter!=.
	label var coupentry "country has at end of year leader who took power in a mil coup"

*	SUMCOUPENTRY
*	This will be helpful for an overtime graph

	capture drop sumcoupentry
	egen sumcoupentry=sum(coupentry), by(year)
	label var sumcoupentry "countries with coup-installed leaders"

* 	COUPHIST
*	number of recent coups 
* 	a weighted average tracking coup-propensity (last 10 yrs, all 1s yields 1, and a 1 closer to last year means more)

	tssmooth ma couphist=hcoups, weights(1/10 <0>)
	label var couphist "10-yr history of coups, ma couphist=hcoups, weights(1/10 <0>)"

*	This was coup-derived info only from Archigoes EXITCODE

*	We can now perform a comparison of different datasets on COUP D'ETAT

	move hcoups exitcode
	move hcoup hcoups

	replace m2scoup=0 if hcoup!=. & m2scoup==.
	replace m2ucoup=0 if hcoup!=. & m2ucoup==.

	label def ssafr 0 "not in Sub-Sah Afr" 1 "Sub-Sah Afr (McGowan coup data)"
	label val ssafr ssafr

	foreach i in a b m m2 {

		gen `i'scoups=`i'scoup
		replace `i'scoup=1 if `i'scoup>0 & `i'scoup!=.
		move `i'scoup `i'scoup

	}


*	Unquote to compare coup datasets:
*	browse ccode country year leader numld ein_outdate tentot exit exitcode hcoup* ascoup* aucoup bscoup* bucoup ssafr mscoup* mucoup m2scoup* m2ucoup scleader ucleader pt* if year>=1945



*	Next we need to know about ELECTIONS so that we can code days to competitive election after coup



*	ELC
*	Competitive election in year, includes whether office of leader contested in year
*	* - we could also base it on bq3...bq20 instead of counting unclear as `yes'

	capture drop elc
	gen elc=(el==1 & bqu3==1 & bqu4==1 & bqu5==1 & bqu20==1) if el!=.
	label var elc "competitive election, elc=(el==1 & bq3==1 & bq4==1 & bq5==1 & bq20==1) if el!=."


*	Determine whether elections, or coup came last in year


*	CDATE
*	Code last date on which coup occurred in year

	capture drop cdate
	gen cdate=. if exitcode!=""

	local N=_N

		forvalues j=1(1)`N' 																																			{

			local k=wordcount(exitcode[`j'])

				forvalues i=1/`k'																																			{

					if ( (  ( real( word(exitcode[`j'], `i') )>=3 & real( word(exitcode[`j'], `i') ) <=8 ) | real( word(exitcode[`j'], `i') )==16 ) ) & hcoup[`j']==1 	{

						replace cdate=date( substr( word(ein_outdate[`j'], `i'), -9, 9 ), "DMY") in `j' 
				
				}		
		}		
	}



*	EDATE
*	Code last date on which election occurred in year, var 

	capture drop edate
	gen edate=. if cdate!=.

	local N=_N

		forvalues j=1(1)`N' 																																		{

			local k=wordcount(electionid[`j'])

			forvalues i=1/`k'																																		{

					if electionid[`j']!=""	& elc[`j']==1																											{

						replace edate=date( word(mdy[`j'], `i'), "DMY") in `j'
				
					}		
			}		
	}




* 	DAYS2ELE
*	Days to Election after coup, only for same year events
*	we not condition on ELC (competitive election) here
* 	but all actual codings of days2ele below have a competitive election end the coup spell

	capture drop days2ele
	gen days2ele=edate-cdate
	replace days2ele=. if days2ele<0
	label var days2ele "days to election after coup"

* 	CEFAIL
*	country's spell between falling into a coup and then moving to elections 


	capture drop cefail
	gen cefail=1 if days2ele>0 & days2ele!=.
	label var cefail "country in coup spell moves to elections in year"


*	CDATE 
*	Identifier for coup spells: a coup spell can end with elections or with another coup

	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. & elc!=1 & cefail!=1 & cefail[_n-1]==. & ccode[_n-1]==ccode

*	Use the spell identifier to code rest of CEFAIL 

	replace cefail=1 if cefail[_n-1]!=1 & cdate==. & cdate[_n-1]!=. & elc==1 & ccode[_n-1]==ccode

*	this marker - var CECYEAR - will be handy, esp for coups that are ended by elections but then there is a new coup in same year, Bolivia

	capture drop cecyear
	gen cecyear=(cefail==. & cdate[_n-1]!=. & cdate!=. & cdate[_n-1]!=cdate & elc==1 & cdate[_n-1]<edate & cdate!=. & edate!=.) if (cdate!=. & exitcode!="") 
	label var cecyear "coup-ele-coup in year"


*	I can now finish up CEFAIL

	replace cefail=1 if cefail==. & cdate[_n-1]!=. & cdate!=. & cdate[_n-1]!=cdate & elc==1 & cdate[_n-1]<edate & cdate!=. & edate!=. 

	replace cefail=0 if cefail==. & cdate!=. 


*	Currently last year of a coup has no coup id:

	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. &  cefail==1  & ccode==ccode[_n-1]



* 	CDATEID and CDATEIDNUM
*	are id's for coup-spells (can end w elections or another coup)
*	based on date of coup and country COW code

	capture drop cdatestr
	gen cdatestr=string(cdate,"%td")

	capture drop cdateid
	egen cdateid=group(ccode cdatestr) if cdate!=., label

	capture drop cdateidnum
	egen cdateidnum=group(ccode cdatestr) if cdate!=.

	drop cdatestr


*	Helpful to have CDATE and EDATE non-missing for entire coup-spell

	format cdate %td
	egen cdate_max=max(cdate), by(cdateid)
	drop cdate
	rename cdate_max cdate
	label var cdate "last date coup took place in year"
	format cdate %td

	format edate %td
	egen edate_max=max(edate) if cdateid!=., by(cdateid)
	drop edate
	rename edate_max edate
	label var edate "date of last election in year"
	format edate %td

*	COUPELEDEM
*	whether coup displaced an electoral democracy

	gen coupeledem=1 if l1.el_rci==1 & hcoup==1
	replace coupeledem=0 if l1.el_rci==0 & hcoup==1
	egen coupeledem_max=max(coupeledem) if cdateid!=., by(cdateid)
	drop coupeledem
	rename coupeledem_max coupeledem
	label var coupeledem "coup against electoral democracy"
	
*	COUPELEDEMTEN
*	whether coup displaced an electoral democracy with some years history

	gen coupeledemten=1 if (l1.el_rci==1 & l2.el_rci==1 & l3.el_rci==1 & l4.el_rci==1 & l5.el_rci==1 & l6.el_rci==1 & l7.el_rci==1) & hcoup==1
	replace coupeledemten=0 if coupeledemten!=1 & hcoup==1
	egen coupeledemten_max=max(coupeledemten) if cdateid!=., by(cdateid)
	drop coupeledemten
	rename coupeledemten_max coupeledemten
	label var coupeledemten "Pre-Coup 15-yrs Dem "


	gen coupeledemshort=1 if shorteldem==1 & hcoup==1
	replace coupeledemshort=0 if coupeledemshort!=1 & hcoup==1
	egen coupeledemshort_max=max(coupeledemshort) if cdateid!=., by(cdateid)
	drop coupeledemshort
	rename coupeledemshort_max coupeledemshort
	label var coupeledemshort "Pre-Coup 1 yr dem"



*	all coups that end with new coups get DAYS2ELE as missing value

	replace days2ele=edate-cdate if days2ele==.
	replace days2ele=edate-cdate[_n-1] if (days2ele==. | days2ele<0) & cecyear==1
	replace days2ele=. if days2ele<0

	capture drop days2elet
	egen days2elet=max(days2ele), by(cdateid)
	replace days2ele=days2elet if days2ele==.
	drop days2elet


* 	CE_T
*	length of spell for cefail, time to elections after coup

	gen ce_t=0 if cdateid!=.
	replace ce_t=ce_t[_n-1]+1 if ce_t[_n-1]!=. & ce_t!=. & cdateid[_n-1]==cdateid[_n]
	label var ce_t "cefail spell: time, 0 to n years, cefail is on"

* 	splines CE_T31...

	mkspline ce_t3 = ce_t, cubic 

* 	CE_FIRST CF_LAST
*	first and last year of coup spell for cefail,

	gen ce_first=(ce_t==0) if cefail!=.
	label var ce_first "first year coup spell cefail spell ce_first=(ce_t==0) if cefail!=."
	egen ce_tmax=max(ce_t), by(cdateid)
	gen ce_last=(ce_tmax==ce_t) if cefail!=.
	label var ce_last "last year coup spell ce_last=(ce_tmax==ce_t) if cefail!=."

*	browse country year electionid notes leader fail ein_outdate entry exit exitcode hcoups elc days2ele cecyear cdateid cdateidnum cdate edate ce_t ce_t34 ptcoup ptmonth ptday if year>=2000 & western==0



*	COUP SPELLS WITH OTHER DATA

	capture drop ccyr
	egen ccyr=group(ccode year), label


*	COUP SPELLS WITH POWELL AND THYNE DATA

	capture drop pt_cdate pt_cefail pt_ce_t

*	PT_CDATE 

*	Identifier for coup spells: a coup spell can end with elections or with another coup

	gen pt_cdate=ccyr if ptcoup==1

	gen pt_cefail=1 if pt_cdate!=. & elc==1

	replace pt_cdate=pt_cdate[_n-1] if pt_cdate==. & pt_cdate[_n-1]!=. & elc!=1 & pt_cefail!=1 & pt_cefail[_n-1]!=1 & ptcoup!=1 & ccode==ccode[_n-1]

	replace pt_cefail=1 if pt_cdate[_n-1]!=. & elc==1 & ccode==ccode[_n-1]

	replace pt_cdate=pt_cdate[_n-1] if pt_cdate==. & pt_cdate[_n-1]!=. & pt_cefail==1 & ptcoup!=1 & ccode==ccode[_n-1]


*	I can now finish up PT_CEFAIL

	replace pt_cefail=0 if pt_cefail==. & pt_cdate!=. 


*	Currently last year of a coup has no coup id:

*	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. &  cefail==1  & ccode==ccode[_n-1]


* 	PT_CE_T
*	length of spell for cefail, time to elections after coup

	gen pt_ce_t=0 if pt_cdate!=.
	replace pt_ce_t=pt_ce_t[_n-1]+1 if pt_ce_t[_n-1]!=. & pt_ce_t!=. & pt_cdate[_n-1]==pt_cdate[_n]
	label var pt_ce_t "pt cefail spell: time, 0 to n years, cefail is on"


*	COUP SPELLS WITH ALESINA DATA

	capture drop as_cdate as_cefail as_ce_t

*	AS_CDATE 

*	Identifier for coup spells: a coup spell can end with elections or with another coup

	gen as_cdate=ccyr if ascoup==1

	gen as_cefail=1 if as_cdate!=. & elc==1

	replace as_cdate=as_cdate[_n-1] if as_cdate==. & as_cdate[_n-1]!=. & elc!=1 & as_cefail!=1 & as_cefail[_n-1]!=1 & ascoup!=1 & ccode==ccode[_n-1]

	replace as_cefail=1 if as_cdate[_n-1]!=. & elc==1 & ccode==ccode[_n-1]

	replace as_cdate=as_cdate[_n-1] if as_cdate==. & as_cdate[_n-1]!=. & as_cefail==1 & ascoup!=1 & ccode==ccode[_n-1]


*	I can now finish up AS_CEFAIL

	replace as_cefail=0 if as_cefail==. & as_cdate!=. 


*	Currently last year of a coup has no coup id:

*	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. &  cefail==1  & ccode==ccode[_n-1]


* 	AS_CE_T
*	length of spell for cefail, time to elections after coup

	gen as_ce_t=0 if as_cdate!=.
	replace as_ce_t=as_ce_t[_n-1]+1 if as_ce_t[_n-1]!=. & as_ce_t!=. & as_cdate[_n-1]==as_cdate[_n]
	label var as_ce_t "Alesina cefail spell: time, 0 to n years, cefail is on"


*	COUP SPELLS WITH BELKIN AND SHOFER DATA

	capture drop bs_cdate bs_cefail bs_ce_t

*	BS_CDATE 

*	Identifier for coup spells: a coup spell can end with elections or with another coup

	gen bs_cdate=ccyr if bscoup==1

	gen bs_cefail=1 if bs_cdate!=. & elc==1

	replace bs_cdate=bs_cdate[_n-1] if bs_cdate==. & bs_cdate[_n-1]!=. & elc!=1 & bs_cefail!=1 & bs_cefail[_n-1]!=1 & bscoup!=1 & ccode==ccode[_n-1]

	replace bs_cefail=1 if bs_cdate[_n-1]!=. & elc==1 & ccode==ccode[_n-1]

	replace bs_cdate=bs_cdate[_n-1] if bs_cdate==. & bs_cdate[_n-1]!=. & bs_cefail==1 & bscoup!=1 & ccode==ccode[_n-1]


*	I can now finish up BS_CEFAIL

	replace bs_cefail=0 if bs_cefail==. & bs_cdate!=. 


*	Currently last year of a coup has no coup id:

*	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. &  cefail==1  & ccode==ccode[_n-1]


* 	BS_CE_T
*	length of spell for cefail, time to elections after coup

	gen bs_ce_t=0 if bs_cdate!=.
	replace bs_ce_t=bs_ce_t[_n-1]+1 if bs_ce_t[_n-1]!=. & bs_ce_t!=. & bs_cdate[_n-1]==bs_cdate[_n]
	label var bs_ce_t "BELKIN SHOFER cefail spell: time, 0 to n years, cefail is on"


*	COUP SPELLS WITH MARSHALL AND MARSHALL DATA

	capture drop m2s_cdate m2s_cefail m2s_ce_t

*	M2S_CDATE 

*	Identifier for coup spells: a coup spell can end with elections or with another coup

	gen m2s_cdate=ccyr if m2scoup==1

	gen m2s_cefail=1 if m2s_cdate!=. & elc==1

	replace m2s_cdate=m2s_cdate[_n-1] if m2s_cdate==. & m2s_cdate[_n-1]!=. & elc!=1 & m2s_cefail!=1 & m2s_cefail[_n-1]!=1 & m2scoup!=1 & ccode==ccode[_n-1]

	replace m2s_cefail=1 if m2s_cdate[_n-1]!=. & elc==1 & ccode==ccode[_n-1]

	replace m2s_cdate=m2s_cdate[_n-1] if m2s_cdate==. & m2s_cdate[_n-1]!=. & m2s_cefail==1 & m2scoup!=1 & ccode==ccode[_n-1]


*	I can now finish up M2S_CEFAIL

	replace m2s_cefail=0 if m2s_cefail==. & m2s_cdate!=. 


*	Currently last year of a coup has no coup id:

*	replace cdate=cdate[_n-1] if cdate==. & cdate[_n-1]!=. &  cefail==1  & ccode==ccode[_n-1]


* 	M2S_CE_T
*	length of spell for cefail, time to elections after coup

	gen m2s_ce_t=0 if m2s_cdate!=.
	replace m2s_ce_t=m2s_ce_t[_n-1]+1 if m2s_ce_t[_n-1]!=. & m2s_ce_t!=. & m2s_cdate[_n-1]==m2s_cdate[_n]
	label var m2s_ce_t "Marshall and Marshall cefail spell: time, 0 to n years, cefail is on"


*	browse country year electionid notes leader fail ein_outdate entry exit exitcode hcoups elc days2ele cecyear cdateid cdateidnum cdate edate ce_t pt* as* bs* m2s* if year>=1945 & western==0

*	Powell and Thyne check how coups after 2004 end

	gen ptcoup04t=ptcoup if year>2004

	egen ptcoup04=max(ptcoup04), by(pt_cdate)

	label var ptcoup04 "powell thyne coup starts after 2004"

	capture drop ptcoup04t

	egen ptcoup04ele=max(pt_cefail) if ptcoup04==1, by(pt_cdate)

	label var ptcoup04ele "powell thyne coup ends in election if start after 2004"




* 	EDATEIN5
*	a better measure for competitive election in 5 years, (based on days2ele and so on edate)

	capture drop edatein5
	gen edatein5=0 if hcoups>0 & hcoups!=.
	replace edatein5=1 if (days2ele/365)<=5 & edatein5!=.	
	egen edatein5_n=max(edatein5), by(cdateid)
	drop edatein5
	rename edatein5_n edatein5
	label var edatein5 "competive elections 5 years after coup"
	label def elein5 0 "no elections in that period" 1 "elections held <5 years after coup"
	label val edatein5 elein5


* 	CESPELL and SUMCESPELL
*	countries w cefail non-missing

	capture drop cespell
	gen cespell=1 if cefail!=.

	egen sumcespell=sum(cespell), by(year)


* 	INCOUT
*	incumbent out, leader in pwr at time of election steps down regularly within six mos of election when cefail==1 (missing for cases that are not ended by elections)
* 	notes:
* 	for years in which cefail==1, election took place - leader who was in office is recorded either in that year or next
* 	and we need to check that leader out date in 6 months and that Archog0s has data for year
* 	and that the exitcode for leader is not -888, which would mean outdate is not a date leader out but dataset ending

	capture drop incout
	gen incout=1 if cefail==1 & ( date( substr(  word(ein_outdate, -1) , -9, 9 ), "DMY") - edate)<=180 & ( date( substr(  word(ein_outdate, -1) , -9, 9 ), "DMY") - edate)>0 & word(exitcode,-1)!="-888"
	replace incout=1 if incout==. & cefail==1 & ( date( substr(  word(ein_outdate[_n+1], 1) , -9, 9 ), "DMY") -edate)<=180 & word(exitcode[_n+1],1)!="-888"
	replace incout=0 if incout==. & cefail==1 & exitcode!=""
	egen incout_m=max(incout), by(cdateid)
	drop incout
	rename incout_m incout
	label var incout "when cefail=1, true if ld in office during election out of office in 6 mos"


* 	COUPLEADEROUT
*	coup leader out, leader who committed coup is not in pwr six months following election (within six mos of election when cefail==1)
* 	whenever incout, it must be the case that the leader who committed the coup is out, too
* 	the rest is to check if the entry date of leader in year after election is after coup began (so coup leader lost pwr even before elections)
* 	or whether coup-leader was in office in yr after election and stayed on for 6 mos or more
*	this coding is somewhat noisy - it does not capture Barrientos in Chile who committed a coup, handed over power only to run and win in elections - coded as 1 even though should be 0 [check names maybe]

	capture drop coupleaderout
	gen coupleaderout=1 if incout==1 & cefail==1
	replace coupleaderout=0 if coupleaderout==. & cefail==1 & ( date( substr(  word(ein_outdate[_n+1], 1) , 11, 9 ), "DMY") - edate) > 180 & ( date( substr(  word(ein_outdate[_n+1], 1) , 1, 9 ), "DMY")==cdate) & incout!=.
	replace coupleaderout=1 if coupleaderout==. & cefail==1 &  ( date( substr(  word(ein_outdate[_n+1], 1) , 1, 9 ), "DMY")-cdate)>=1 & incout!=. 
	egen coupleaderout_m=max(coupleaderout), by(cdateid)
	drop coupleaderout
	rename coupleaderout_m coupleaderout
	label var coupleaderout "when cefail=1, true if coup ld in office 6 mos after election"



* 	ELENDSCOUP
*	how many coups followed by election (ever) as opposed by another coup

	gen elendscoup=1 if (edatein5!=. & days2ele!=.) & hcoup==1
	replace elendscoup=0 if (edatein5!=. & days2ele==.) & hcoup==1
	egen elendscoup_n=max(elendscoup), by(cdateid)
	drop elendscoup
	rename elendscoup_n elendscoup
	label var elendscoup "coup ends w ele (or 0 w coup/ongoing) =0/1 (edatein5!=. & days2ele==./!=.) & hcoup==1"


* 	COUPENDED
*	is 1 if either coup or elections end a coup spell

	gen coupended_t=1 if (days2ele!=. | (cecyear==1 & hcoup==1)) & cefail!=. & year==2004
	replace coupended_t=0 if coupended_t==. & cefail!=. & year==2004
	egen coupended=max(coupended_t), by(cdateidnum)
	replace coupended=1 if coupended==. & cefail!=.
	label var coupended "coup has ended (2004 Archigos or 2006 YEP)"
	drop coupended_t

*	HCOUP0 and HCOUP1
*	Did coup take place before or after 1991

	capture drop hcoup0 hcoup1
	gen hcoup0=(hcoup==1 & postcw==0)
	gen hcoup1=(hcoup==1 & postcw==1)
	egen hcoup0_m=max(hcoup0) if cdateid!=., by(cdateid)
	egen hcoup1_m=max(hcoup1) if cdateid!=., by(cdateid)
	replace hcoup0_m=0 if hcoup0_m==. & hcoup1_m==1
	replace hcoup1_m=0 if hcoup1_m==. & hcoup0_m==1
	drop hcoup0 hcoup1
	rename hcoup0_m hcoup0
	rename hcoup1_m hcoup1
	label var hcoup0 "coup took place before 1991, hcoup0=(hcoup==1 & postcw==0)"
	label var hcoup1 "coup took place on or after 1991, hcoup1=(hcoup==1 & postcw==1)"
	
*	note ce_tmax=0 for 1 yr events

	replace ce_tmax=ce_tmax+1

*	mean t to election for coups by year conditional on ending w elections

	egen mean_t2ele=mean(ce_tmax) if hcoup==1 & elendscoup==1, by(year)


*	C_PATH and HCOUP1_PATH will be handy for Polity Graph over t

*	VAR C_PATH
*	Counts years since last coup: does not revert to missing after elections end coup spell

	sort ccode year

	gen c_path=ce_t
	replace c_path=c_path[_n-1]+1 if ccode==ccode[_n-1] & c_path==.
	replace c_path=-1 if ccode==ccode[_n+1] & c_path[_n+1]==0

	label var c_path "years since coup"

*	VAR HCOUP1_PATH
*	whether coup took place after cold war: does not revert to missing after elections end coup spell

	gen hcoup1_path=hcoup1
	replace hcoup1_path=hcoup1_path[_n-1] if ccode==ccode[_n-1] & hcoup1_path==.

	label var hcoup1_path "period in which coup took place"
	label val hcoup1_path cw
	


*	SUMAUTO
*	autogolpes by year
	egen sumauto=sum(autogolpe), by(year)
	egen ymark=tag(year)


*	PREODADEP
*	odadep lagged to year before coup starting spell

	gen preodadep=l1.odadep if hcoup==1
	egen preodadep_max=max(preodadep) if cdateid!=., by(cdateid)
	drop preodadep
	rename preodadep_max preodadep
	label var preodadep "aid dependence, lagged to year before coup that starts spell"


*	COUPDEPCHANGE
*	How does ODA dependence change in year of coup?

	gen coupdepchange=odadep-preodadep if hcoup==1	
	label var coupdepchange "odadep-l1.odadep if hcoup==1"

*	ODAIN5
*	What about ODA dependence for the first five years of the coup spell for ones that end in elections and for those that do not, after 1991?	
	
	sort cdateid
	by cdateid: egen odain5=mean(odadep) if ce_t<=4
	label var odain5 "aid dep mean of country <=5 years into coup"

	sort ccode year

	gen gdppc=gdpM/wbpop
*	wbpoptot is sth I got from WB Dev Ind
	replace gdppc=gdpM/wbpoptot if gdppc==.
	gen lngdppc=log(gdppc)

	capture drop growth
	gen growth=(l1.gdpM-l2.gdpM)/l2.gdpM
	label var growth "growth prev year, =(l1.gdpM-l2.gdpM)/l2.gdpM"

* 	Using newer WB data on gdp, pop to gen lnwbgdppc, wbodadep, growth

	capture drop wbgdppc lnwbgdppc wbodadep

* 	WB gdp is in current $, use Sahr defl to first convert it to const 1995 $

	gen wbgdp_current=wbgdp						
	move wbgdp_curr wbgdp
	replace wbgdp=wbgdp/cf_1995
	label var wbgdp " World Bank GDP (dev ind) in 1995 const $, Sahr deflator"

*	growth

	capture drop wbgrowth
	gen wbgrowth=(l1.wbgdp-l2.wbgdp)/l2.wbgdp
	label var wbgrowth "growth prev year (WB gdp data), =(l1.wbgdp-l2.wbgdp)/l2.wbgdp"

*	...per capita

	gen wbgdppc=wbgdp/wbpoptot
	label var wbgdppc "WB Dev Indicators, =wbgdp/wbpoptot"

*	...log of that

	gen lnwbgdppc=log(wbgdppc)
	label var lnwbgdppc "WB Dev Indicators, =log(wbgdp/wbpoptot)"

*	odadep

	capture drop wbodadep
	gen wbodadep=(oda*1000000)/wbgdp
	label var wbodadep "WB Dev Indicators and OECD aid, =oda*1000000/wbgdp"







*						------------------------ 											End of Data Generation 								-------------------










*						------------------------ 											Analysis/Graphs/Summaries 								-------------------









*
*
*
*		COUPS ->
*
*
*



*		Interesting DESCRIPTIVES


*		Successful coups in year over time, plus number of cs with leader who came to power through coup

*		Figure \ref{overview}

		graph twoway (bar sumhcoups year, barw(.4) yaxis(1)) (line sumcoupentry year, sort yaxis(2)) if year>=1945 & year<=2004, ///	
		ylabel(0(2)12) yscale(r(0,20)) ///
		ylabel(10(5)40, axis(2)) yscale(axis(2) r(0,40)) ///
		xlabel(1945(5)2005) xtitle("") ///
		title("") subtitle("") note("") plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		legend(off)

		graph export "graphs/coups_ld.eps", replace
		graph export "graphs/coups_ld.tif", width(1100) height(800) replace


*		Pie Chart - % elections in 5 years after coup, by CW 

*		Figure \ref{fig:pie}
*		in older versions: Figure \ref{pie_edatein5}

*		For "note" in pie chart: 216 in 1945-1990, 43 in 1991-2004 - 259 coups total

		capture label drop postcw_coups
		label def postcw_coups 0 "1945-1990: 216 coups" 1 "1991-2004: 43 coups"
		label val postcw postcw_coups

		table ones, by(postcw)
		table edatein5 if ones==1, by(postcw)

*		if you want white graph region:
*		graph pie ones, over(edatein5) ///						
*		by(postcw, graphregion(fcolor(white)) title("") subtitle("") note("")) /// 						
*		pie(1, explode color(none)) pie(2, color(midblue)) plabel(_all percent, format(%9.0f) size(*1.5)) ///						
*		line(lwidth(thin) lcolor(midblue)) ///						
*		legend(rows(1) order(2 1) region(lcolor(none) fcolor(none))) 						
*							
*		graph export "/Users/nvm4/Documents/localtexmf/img_coups/pie_edatein5.eps", replace						

		graph pie ones, over(edatein5) ///
		by(postcw, title("") subtitle("") note("")) /// 
		graphregion(fcolor(white)) graphregion(color(white)) plotregion(fcolor(white)) plotregion(style(none)) ///
		pie(1, explode color(none)) pie(2, color(midblue)) plabel(_all percent, format(%9.0f) size(*1.5)) ///
		line(lwidth(thin) lcolor(midblue)) ///
		legend(rows(1) order(2 1) region(lcolor(none) fcolor(none))) 

		graph export "graphs/pie_edatein5.eps", replace
		graph export "graphs/pie_edatein5.tif", width(1100) height(800) replace


*		Graph of Polity Trajectory of countries experiencing coups
*		Figure \ref{p2trajectory}


		graph bar (mean) polity2 if c_path<=7 & year>1950, over(c_path) by(hcoup1_path, plotregion(fcolor(white)) graphregion(fcolor(white)) note("")) ///
		intensity(*.2) outergap(*3) bargap(100) yscale(r(-5 5)) bar(1, color(black)) ///
		title("") subtitle(, fcolor(white))
		graph export "graphs/p2trajectory.eps", replace
		graph export "graphs/p2trajectory.tif", width(1100) height(800) replace




*		BITE OF POST-COUP ELECTIONS

*		use line below to get information on cases
*		
*		browse country year leader exitcode ein_out hcoup ones cdateid cefail polity2 ce_t edate days2ele edatein5 coupleaderout bqu39 el_m el_f electionid elc elendscoup coupended odadep if western==0 & year>=1960 & cefail!=.

*		Incumbent replaced after election

*		In siginificant proportion of cases of coups ending in elections, incumbent on eve of elections is replaced, after CW ends, only for coups starting after 1991 (INCOUT is non-missing only if ele end coup eventually)

		table incout if cefail==1, by(postcw)

*		decision to only look at whether inc is replaced also by when did coup begin - idea is that some pre-CW coup leaders held fake elections after 1990		

*		begins in cw
		
		table incout if cefail==1 & hcoup0==1, by(postcw)
		
*		begins before cw
		
		table incout if cefail==1 & hcoup1==1, by(postcw)

*       Seems like coups that began before 1990 and ended after 1990 were least likely to result in inc losing job in elections

		table bqu39 if cefail==1, by(postcw)

		table bqu39 if cefail==1, by(postcw hcoup1)

*		the average for all elections in firing inc

		table bqu39, by(postcw)

*		=> The rate at which coup-leaders lose elections after 1990 is, if anything, higher than the rate at which incumbents more generally lose elections: and this applies to 1991 on as well as to pre-1991

*		Was coup leader in office after the election? A measure of elections and their bite, based on Archigos

*		In slightly under 80 per cent of cases of coups ending in elections, coup leader was not in office after elections
*		difference is not great between this and var asking "was inc in office, INCOUT"

		table coupleaderout if cefail==1, by(postcw hcoup1)

*		If we look at fraud in elections ending coups, only number for after cw reported as too few observers before 1990 - about 16 per cent of cases with fraud

		table el_f if cefail==1 & year<=2010, by(postcw)
		
*		Cheibub Democratization Measures - after elections following coups

		count if l1.reg==0 & f1.reg==1 & cefail==1 & year<1991
		count if l1.reg==1 & f1.reg==1 & cefail==1 & year<1991

		count if l1.reg==0 & f1.reg==0 & cefail==1 & year<1991
		count if l1.reg==1 & f1.reg==0 & cefail==1 & year<1991

*		50 % based on 46 cases

		count if l1.reg==0 & f1.reg==1 & cefail==1 & year>=1991
		count if l1.reg==1 & f1.reg==1 & cefail==1 & year>=1991

		count if l1.reg==0 & f1.reg==0 & cefail==1 & year>=1991
		count if l1.reg==1 & f1.reg==0 & cefail==1 & year>=1991

*		51 % based on 43 cases


*		How often did democracy falter due to coups between 1960 and 2001
*		76 % of the failures

		sort ccode year
		count if l1.reg==1 & reg==0 & hcoup==1
*		48 (the subset)
		count if l1.reg==1 & reg==0
*		66 (the full set)



*	REGRESSIONS




	
		
*		
*		**************************************** REGRESSSIONS ***************************************************
*		
		
						
	tsset ccode year	
	gen odadepL1=l1.odadep	
	gen lngdppcL1=l1.lngdppc	
	gen odadepLpcw=l1.odadep*postcw	
	gen lngdppcLpcw=l1.lngdppc*postcw	
	gen growthLpcw=growth*postcw	
	gen colfrapcw=colfra*postcw	
	gen coupeledempcw=coupeledem*postcw	
	gen milcouppcw=milcoup*postcw	
	gen ce_tpcw=ce_t*postcw	
	gen ce_tsq = ce_t*ce_t	
	gen couphistpcw=couphist*postcw	
	gen el_rciLpcw=l1.el_rci*postcw
	
	
	label var	 	hcoup		"Coup Archigos"
	label var	 	odadepL1	"Aid Dependence"
	label var	 	lngdppcL1	"GDP per capita"
	label var	 	growth		"Economic Growth"
	*growth is lagged
	label var	 	couphist	"Coup History"
	label var	 	colfra		"Ex-French Colony"
	label var	 	ce_t		"Years since Coup"
	label var	 	milcoup		"Military Actors"
	label var	 	hcoup0		"Cold War Coup"
	label var	 	coupeledem	"Pre-Coup Dem"
	label var	 	postcw		"Post Cold War"
	label var	 	lngdppcLpcw	"Post x GDP pc"
	label var	 	growthLpcw	"Post x Econ Growth"
	label var	 	milcouppcw	"Post x Military"
	label var	 	ce_tpcw 	"Post x Years Since Coup"
	label var	 	odadepLpcw	"Post x Aid Dep"
	label var 		colfrapcw	"Post x Ex-French Colony"
	label var 		coupeledempcw	"Post x Pre-Coup Dem"
	

*	time to election	

*	Table \ref{tab:res1}

	probit cefail odadepL1 lngdppcL1 growth colfra coupeledem milcoup ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using tabres1, ctitle(1960-1990) label e(N ll) replace  

	probit cefail odadepL1 lngdppcL1 growth colfra coupeledem milcoup ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using tabres1, ctitle(1991--) label e(N ll) append  

	probit cefail odadepL1 lngdppcL1 growth colfra coupeledem milcoup ce_t postcw  odadepLpcw, vce(cluster cdateid)	
	outreg2 using tabres1, ctitle(ALL) label e(N ll) append tex 

*	Clarify, using Model III above

	capture drop b1-b11
	estsimp	probit cefail odadepL1 lngdppcL1 growth colfra coupeledem milcoup ce_t couphist postcw  odadepLpcw, vce(cluster cdateid)
	setx odadepL1 0 (lngdppcL1 growth) mean (colfra coupeledem milcoup couphist) median (postcw odadepLpcw) 0 ce_t 5
	simqi, prval(1)
	setx odadepL1 .5 (lngdppcL1 growth) mean (colfra coupeledem milcoup couphist) median (postcw odadepLpcw) 0 ce_t 5
	simqi, prval(1)
	setx odadepL1 0 (lngdppcL1 growth) mean (colfra coupeledem milcoup couphist) median postcw 1 odadepLpcw 0 ce_t 5
	simqi, prval(1)
	setx odadepL1 .5 (lngdppcL1 growth) mean (colfra coupeledem milcoup couphist) median postcw 1 odadepLpcw 0.5 ce_t 5
	simqi, prval(1)
	capture drop b1-b11



*	Predicted probabilities Graph

*	Figure \ref{fig:pred.probs}

*	R code

*	dd <- c("/Users/nvm4/Documents/E-Library/Democracy/Goemans Marinov Coup/Publication/repdata")
*	
*	setwd(dd)
*	
*	pdf("probs.pdf", width=7, height=5, paper="special")
*	
*	par(mar=c(3,5,1,1))
*	
*	y <- c(0.0,0.5)
*	x <- c(0.75,4.25)
*	
*	op.m<-c(.058, .030, .135, .289)
*	op.se<-c(.017, .026, .032, .081)
*	
*	plot(x,y,type="n",xlab="",ylab="Pr(Elections)",cex.main=1.5, frame.plot=T,axes=F)
*	axis(1,1:4,tick=F,labels=c("Low \n Pre-","High \n Pre-","Low \n Post-","High  \n Post-"),cex.axis=1)
*	axis(2,at=c(0.05,0.10,0.15,0.20,0.25,0.3,0.35,0.4,0.45))
*	segments(1:4, op.m-1.96*op.se, 1:4, op.m+1.96*op.se, col="black", lwd=1.5)
*	points(1:4, op.m, pch=19, cex=1)
*	#segments(1:3, c(op.m[1:3]), 2:4, c(op.m[2:4]),lty=3)
*	
*	
*	dev.off()




*	Table \ref{tab:res2}
		
	probit cefail odadepL1 lngdppcL1 coupeledem milcoup postcw, vce(cluster cdateid)	
	outreg2 using tabres2, label e(N ll) replace  

	probit cefail odadepL1 lngdppcL1 coupeledem milcoup postcw odadepLpcw, vce(cluster cdateid)	
	outreg2 using tabres2, label e(N ll) append  

	probit cefail odadepL1 lngdppcL1 coupeledem coupeledemshort milcoup postcw odadepLpcw, vce(cluster cdateid)	
	outreg2 using tabres2, label e(N ll) append  

	probit cefail odadepL1 lngdppcL1 growth colfra coupeledem milcoup ce_t postcw odadepLpcw growthLpcw coupeledempcw colfrapcw milcouppcw, vce(cluster cdateid)	
	outreg2 using tabres2, ctitle(all interact) label e(N ll) append tex 



*	DISCUSSION	

*	Coups and Aid Changes

*	shows that unlike before now in year of coup aid is reduced 

	ttest coupdepchange if hcoup==1, by(postcw)


*	this evolves differently for postCW cases that end in elections than for those postCW cases that do not:

	sort edatein5

	by edatein5: sum odain5 if hcoup==1 & year>=1991
	
	

		
*	Delay of election after coup and its effect on aid as percentage of GDP	

*	Table \ref{tab:aidpostcoup}
		
	regress odadep growth lngdpM hcoup0 ce_t postcw growthLpcw ce_tpcw if year>=1960 & year<2002 	
	outreg2 using tabres3, ctitle(all interact) label e(N r2) tex replace	
	
	test ce_t=ce_tpcw 	
		
	lincom ce_t + ce_tpcw 	
						
					

*		
*	*regress odadep hcoup postcw hcouppcw folfra l1.odadep l1.lngdppc l1.growth l1.el_rfc, vce(cluster ccode) 	
*		
*		
*		
*	*heckman days2ele l1.odadep l1.growth colfra coupeledem milcoup , select(hcoup couphist l1.odadep l1.growth colfra coupeledem milcoup ), if postcw==0 	
*		
*		
*		

*	Appendix Who has been having coups?	



*	Regression of likelihood of coup 

*	conditioning makes sure that we are looking for coups only outside of coup-to-election spells (once in a coup spell, we do not model likelihood of having another coup)

	sort ccode year
	
	logit hcoup l1.odadep l1.lngdppc l1.growth couphist l1.el_rci colfra if (ce_t==0 | ce_t==.) & year<1991, vce(cluster ccode)

*	outreg2 using hcoup.doc, nolabel

	capture est drop h1960
	
	est store h1960

	logit hcoup l1.odadep l1.lngdppc l1.growth couphist l1.el_rci colfra if (ce_t==0 | ce_t==.) & year>=1991, vce(cluster ccode)

*	outreg2 using hcoup.doc, nolabel append

	capture est drop h1991
	
	est store h1991

	estimates table h1960 h1991, b(%7.4f) se(%7.4f) stats(N r2_a)
	
	estimates table h1960 h1991, b(%7.4f) star stats(N r2_a)


*	Table \ref{tab:res.coups} Likelihood of coups in appendix


	probit hcoup l1.odadep l1.lngdppc l1.growth colfra l1.el_rci couphist if (ce_t==0 | ce_t==.) & year<1991, vce(cluster ccode)
	outreg2 using tabrescoups, ctitle("Pre-") label e(N ll) replace

	probit hcoup l1.odadep l1.lngdppc l1.growth colfra l1.el_rci couphist if (ce_t==0 | ce_t==.) & year>1990, vce(cluster ccode)
	outreg2 using tabrescoups, ctitle("Post-") label e(N ll) append 

	probit hcoup l1.odadep l1.lngdppc l1.growth colfra l1.el_rci couphist postcw odadepLpcw lngdppcLpcw el_rciLpcw if (ce_t==0 | ce_t==.), vce(cluster ccode)
	outreg2 using tabrescoups, ctitle("All") label e(N ll) append tex



*	ONLINE APPX

*	Different coups data

*	This table will have five columns: Archigos, Alesina, Belkin Schofer, Marshall and Marshall, Powell Thyne - for pre-1991
*	Tables \ref{tab:diff.coups.1960} and \ref{tab:diff.coups.1991} 

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=cefail
	gen diff_ce_t=ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using diffcoup1960, ctitle(Arch) label e(N ll) replace

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=as_cefail
	gen diff_ce_t=as_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using diffcoup1960, ctitle(Ales) label e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=bs_cefail
	gen diff_ce_t=bs_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using diffcoup1960, ctitle(BelSch) label e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=m2s_cefail
	gen diff_ce_t=m2s_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using diffcoup1960, ctitle(MM) label  e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=pt_cefail
	gen diff_ce_t=pt_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year<1991, vce(cluster cdateid)	
	outreg2 using diffcoup1960, ctitle(PowTh) label e(N ll) append tex 

*	This table will have five columns: Archigos, Alesina, Belkin Schofer, Marshall and Marshall, Powell Thyne - for post-1991
*	Tables \ref{tab:diff.coups.1991} 

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=cefail
	gen diff_ce_t=ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using diffcoup1991, ctitle(Arch) label e(N ll) replace

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=as_cefail
	gen diff_ce_t=as_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using diffcoup1991, ctitle(Ales) label e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=bs_cefail
	gen diff_ce_t=bs_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using diffcoup1991, ctitle(BelSch) label e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=m2s_cefail
	gen diff_ce_t=m2s_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using diffcoup1991, ctitle(MM) label e(N ll) append  

	capture drop diff_cefail diff_ce_t
	gen diff_cefail=pt_cefail
	gen diff_ce_t=pt_ce_t

	probit diff_cefail odadepL1 lngdppcL1 growth colfra diff_ce_t if year>1990, vce(cluster cdateid)	
	outreg2 using diffcoup1991, ctitle(PowTh) label e(N ll) append tex 

*	Different decades

	capture drop dec70* dec80*
	gen dec70=year>1970 & year<1981
	label var dec70 "1970s"
	gen dec80=year>1980 & year<1991
	label var dec80 "1980s"
	gen dec70Lodadep=dec70*odadepL1
	label var dec70Lodadep "1970s x Aid"
	gen dec80Lodadep=dec80*odadepL1
	label var dec80Lodadep "1980s x Aid"

*	Table \ref{tab:diff.decades}
	
	probit cefail odadepL1 lngdppcL1 growth colfra ce_t postcw, vce(cluster cdateid)	
	outreg2 using diffdecades, ctitle(By CW) label e(N ll) replace

	probit cefail odadepL1 lngdppcL1 growth colfra ce_t dec70 dec80 postcw, vce(cluster cdateid)	
	outreg2 using diffdecades, ctitle(By Dec) label e(N ll) append

	probit cefail odadepL1 lngdppcL1 growth coupeledem colfra ce_t postcw odadepLpcw, vce(cluster cdateid)	
	outreg2 using diffdecades, ctitle(Dem) label e(N ll) append

	probit cefail odadepL1 lngdppcL1 growth coupeledemten colfra ce_t postcw odadepLpcw, vce(cluster cdateid)	
	outreg2 using diffdecades, ctitle(Old Dem) label e(N ll) append tex


*	R Script for Structural Break Figure

*	To turn the panel data into time-series using Stata for the structural break:			
*		
*	collapse (mean) edatein5, by(year)	
*		
*	drop if year>2001 | year<1960	
*		
*	save "structural break-3.dta"	
*		
*	rm(list=ls())
*	
*	library(foreign)
*	
*	library(strucchange)
*	
*	library(stats)
*	
*	library(Hmisc)
*	
*	
*	struc.change.3.data <- read.dta("C:/Documents and Settings/hgoemans/My Documents/Hgoemans/Leaders/Marinov/Coup Project/structural break-3.dta", convert.dates=FALSE)
*	
*	struc.change.3.data<-subset(struc.change.3.data, days2ele!="NA")
*	
*	
*	#struc.change.3.data<-subset(struc.change.3.data, year>=1970)
*	
*	
*	attach(struc.change.3.data)
*		
*	
*	## Test null hyp that days to election stay the same: Str'l Change in 1991.
*	
*	postcw.3 <- structure(edatein5, .Tsp=c(1960,2001,1),class="ts")
*	
*	fs.postcw.3<- Fstats(postcw.3 ~ 1, from=c(2),to=c(41)) 
*	
*	plot(fs.postcw.3,main="Structural Change Point") 
*	
*	sctest(fs.postcw.3)
*	
*	lines(breakpoints(fs.postcw.3))




/*


*/
